@@ -1,5 +1,5 @@
 package DateTime::TimeZone::Local::Win32;
-$DateTime::TimeZone::Local::Win32::VERSION = '1.87';
+$DateTime::TimeZone::Local::Win32::VERSION = '1.88';
 use 5.006;
 
 use strict;
@@ -22,6 +22,7 @@ sub EnvVars { return 'TZ' }
         'Afghanistan Standard Time'       => 'Asia/Kabul',
         'Alaskan'                         => 'America/Anchorage',
         'Alaskan Standard Time'           => 'America/Anchorage',
+        'Altai Standard Time'             => 'Asia/Barnaul',
         'Arab'                            => 'Asia/Riyadh',
         'Arab Standard Time'              => 'Asia/Riyadh',
         'Arabian'                         => 'Asia/Muscat',
@@ -29,6 +30,7 @@ sub EnvVars { return 'TZ' }
         'Arabic Standard Time'            => 'Asia/Baghdad',
         'Argentina Standard Time'         => 'America/Argentina/Buenos_Aires',
         'Armenian Standard Time'          => 'Asia/Yerevan',
+        'Astrakhan Standard Time'         => 'Europe/Astrakhan',
         'Atlantic'                        => 'America/Halifax',
         'Atlantic Standard Time'          => 'America/Halifax',
         'AUS Central'                     => 'Australia/Darwin',
@@ -157,6 +159,7 @@ sub EnvVars { return 'TZ' }
         'SA Pacific Standard Time'        => 'America/Bogota',
         'SA Western'                      => 'America/Guyana',
         'SA Western Standard Time'        => 'America/Guyana',
+        'Sakhalin Standard Time'          => 'Asia/Sakhalin',
         'Samoa'                           => 'Pacific/Apia',
         'Samoa Standard Time'             => 'Pacific/Apia',
         'Saudi Arabia'                    => 'Asia/Riyadh',
@@ -178,6 +181,7 @@ sub EnvVars { return 'TZ' }
         'Tokyo'                           => 'Asia/Tokyo',
         'Tokyo Standard Time'             => 'Asia/Tokyo',
         'Tonga Standard Time'             => 'Pacific/Tongatapu',
+        'Transbaikal Standard Time'       => 'Asia/Chita',
         'Turkey Standard Time'            => 'Europe/Istanbul',
         'Ulaanbaatar Standard Time'       => 'Asia/Ulaanbaatar',
         'US Eastern'                      => 'America/Indianapolis',
@@ -291,7 +295,7 @@ DateTime::TimeZone::Local::Win32 - Determine the local system's time zone on Win
 
 =head1 VERSION
 
-version 1.87
+version 1.88
 
 =head1 SYNOPSIS
 
